@@ -3,14 +3,15 @@ Main interface for datapipeline service.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.datapipeline import (
+    from mypy_boto3_datapipeline import (
         Client,
         DataPipelineClient,
         DescribeObjectsPaginator,
         ListPipelinesPaginator,
         QueryObjectsPaginator,
-        )
+    )
 
     session = boto3.Session()
 
@@ -20,6 +21,7 @@ Usage::
     describe_objects_paginator: DescribeObjectsPaginator = client.get_paginator("describe_objects")
     list_pipelines_paginator: ListPipelinesPaginator = client.get_paginator("list_pipelines")
     query_objects_paginator: QueryObjectsPaginator = client.get_paginator("query_objects")
+    ```
 """
 from mypy_boto3_datapipeline.client import DataPipelineClient as Client, DataPipelineClient
 from mypy_boto3_datapipeline.paginator import (
